@@ -1,5 +1,5 @@
 #
-# $Id: PatternTcpFlags.pm,v 1.1.2.10.2.2 2006/05/31 16:49:57 gomor Exp $
+# $Id: PatternTcpFlags.pm,v 1.1.2.12.2.3 2006/06/11 17:18:53 gomor Exp $
 #
 package Net::SinFP::DB::PatternTcpFlags;
 use strict;
@@ -10,16 +10,21 @@ our @ISA = qw(DBIx::SQLite::Simple::Table);
 
 our @AS = qw(
    idPatternTcpFlags
-   patternTcpFlags
+   patternTcpFlagsHeuristic0
    patternTcpFlagsHeuristic1
    patternTcpFlagsHeuristic2
 );
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
+our $Id     = $AS[0];
+our @Fields = @AS[1..$#AS];
+
+1;
+
 =head1 NAME
 
-Net::SinFP::DB::PatternTcpFlags - PatternTcpFlags SQL table
+Net::SinFP::DB::PatternTcpFlags - PatternTcpFlags database table
 
 =head1 DESCRIPTION
 
@@ -27,21 +32,6 @@ Go to http://www.gomor.org/sinfp to know more.
 
 =cut
 
-our $Id     = qw(idPatternTcpFlags);
-our @Fields = qw(
-   patternTcpFlags patternTcpFlagsHeuristic1 patternTcpFlagsHeuristic2
-);
-
-sub getTcpFlags {
-   shift->lookupString('patternTcpFlags', idPatternTcpFlags => shift);
-}
-sub getTcpFlagsH1 {
-   shift->lookupString('patternTcpFlagsHeuristic1', idPatternTcpFlags => shift);
-}
-sub getTcpFlagsH2 {
-   shift->lookupString('patternTcpFlagsHeuristic2', idPatternTcpFlags => shift);
-}
-
 =head1 AUTHOR
 
 Patrice E<lt>GomoRE<gt> Auffret
@@ -54,5 +44,3 @@ You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
 =cut
-
-1;
